Index: include/asterisk/monitor.h
===================================================================
--- include/asterisk/monitor.h  (revision 92206)
+++ include/asterisk/monitor.h  (working copy)
@@ -31,10 +31,16 @@
 };

 /* Streams recording control */
-#define X_REC_IN       1
-#define X_REC_OUT      2
-#define X_JOIN         4
+enum {
+       X_REC_IN =              ( 1<<0 ),
+       X_REC_OUT =             ( 1<<1 ),
+       X_JOIN =                ( 1<<2 ),
+       X_WAITFORBRIDGE =       ( 1<<3 ),
+};
+/* number of enum entries  */
+#define        X_ARRAY_SIZE    4

+
 /*! Responsible for channel monitoring data */
 struct ast_channel_monitor {
        struct ast_filestream *read_stream;
Index: res/res_monitor.c
===================================================================
--- res/res_monitor.c   (revision 92206)
+++ res/res_monitor.c   (working copy)
@@ -85,6 +85,15 @@
 "monitored, otherwise 0.\n"
 ;

+
+AST_APP_OPTIONS(monitor_options, BEGIN_OPTIONS
+    AST_APP_OPTION('m', X_JOIN),
+    AST_APP_OPTION('b', X_WAITFORBRIDGE),
+    AST_APP_OPTION('i', X_REC_IN),
+    AST_APP_OPTION('o', X_REC_OUT),
+END_OPTIONS);
+
+
 static char *stopmonitor_synopsis = "Stop monitoring a channel";

 static char *stopmonitor_descrip = "  StopMonitor():\n"
@@ -435,12 +444,12 @@
 {
        char *arg = NULL;
        char *options = NULL;
+       struct ast_flags opts = { 0, };
+       char *opt_args[X_ARRAY_SIZE];
        char *delay = NULL;
        char *urlprefix = NULL;
        char tmp[256];
-       int stream_action = X_REC_IN | X_REC_OUT;
        int joinfiles = 0;
-       int waitforbridge = 0;
        int res = 0;
        char *parse;
        AST_DECLARE_APP_ARGS(args,
@@ -458,15 +467,13 @@
        parse = ast_strdupa((char*)data);
        AST_STANDARD_APP_ARGS(args, parse);

-       if (strchr(args.options, 'm'))
-               stream_action |= X_JOIN;
-       if (strchr(args.options, 'b'))
-               waitforbridge = 1;
-       if (strchr(args.options, 'i'))
-               stream_action &= ~X_REC_IN;
-       if (strchr(args.options, 'o'))
-               stream_action &= ~X_REC_OUT;
+       if (!ast_strlen_zero(args.options)) {
+               ast_app_parse_options(monitor_options, &opts, opt_args, args.options);
+       }

+       /* invert options 'i' and 'o', because they mean 'skip recording', and by default recording for input and output is enabled. */
+       opts.flags ^= X_REC_IN | X_REC_OUT;
+
        arg = strchr(args.format, ':');
        if (arg) {
                *arg++ = 0;
@@ -480,7 +487,7 @@
                        return -1;
                ast_cdr_setuserfield(chan, tmp);
        }
-       if (waitforbridge) {
+       if (ast_test_flag(&opts, X_WAITFORBRIDGE)) {
                /* We must remove the "b" option if listed.  In principle none of
                   the following could give NULL results, but we check just to
                   be pedantic. Reconstructing with checks for 'm' option does not
@@ -497,12 +504,12 @@
                return 0;
        }

-       res = ast_monitor_start(chan, args.format, args.fname_base, 1, stream_action);
+       res = ast_monitor_start(chan, args.format, args.fname_base, 1, opts.flags);
        if (res < 0)
                res = ast_monitor_change_fname(chan, args.fname_base, 1);

-       if (stream_action & X_JOIN) {
-               if ((stream_action & X_REC_IN) && (stream_action & X_REC_OUT))
+       if (ast_test_flag(&opts, X_JOIN)) {
+               if (ast_test_flag(&opts, X_REC_IN) && ast_test_flag(&opts, X_REC_OUT))
                        joinfiles = 1;
                else
                        ast_log(LOG_WARNING, "Won't mix streams unless both input and output streams are recorded\n");
